@@ -2,7 +2,7 @@
  *	File:		rbamtools.c
  *
  * 	Created on:	17.06.2011
- *  	Author: 	Wolfgang Kaisers
+ *  Author: 	Wolfgang Kaisers
  *	Content:	C Header File for R package rbamtools
  */
 
@@ -18,17 +18,28 @@
 #include "samtools/bam.h"
 #include "samtools/sam.h"
 #include "align_list.h"
+#include "gap_list.h"
 
 const char * const CIGAR_TYPES="MIDNSHP=X";
 
 inline int cigar2str(char *c,const bam1_t *align);
+bam_header_t* clone_bam_header(bam_header_t *h);
 SEXP is_nil_externalptr(SEXP ptr);
 
+///////////////////////////////////////////////////////////////////////////////////////////////////
+// bamHeader
+///////////////////////////////////////////////////////////////////////////////////////////////////
+
+static void finalize_bam_header(SEXP ptr);
+SEXP init_bam_header(SEXP pHeaderText);
+SEXP bam_header_get_header_text(SEXP pHeader);
+
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 // BamWriter
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 static void finalize_bam_writer(SEXP ptr);
-SEXP bam_writer_open(SEXP pReader,SEXP pFilename);
+SEXP bam_writer_open(SEXP pHeader,SEXP pFilename);
+SEXP bam_reader_open_writer(SEXP pReader,SEXP pFilename);
 SEXP bam_writer_save_align(SEXP pWriter, SEXP pAlign);
 SEXP bam_writer_close(SEXP pWriter);
 
@@ -47,18 +58,33 @@ SEXP bam_reader_load_index(SEXP idx_file);
 SEXP bam_reader_unload_index(SEXP pIdx);
 SEXP bam_reader_get_next_align(SEXP pReader);
 SEXP bam_reader_sort_file(SEXP pFilename,SEXP pPrefix,SEXP pMaxMem,SEXP pByName);
+SEXP bam_reader_get_header(SEXP pReader);
+
+///////////////////////////////////////////////////////////////////////////////////////////////////
+// GapList
+///////////////////////////////////////////////////////////////////////////////////////////////////
+
+static void finalize_gap_list(SEXP ptr);
+SEXP create_gap_list();
+static int gap_fetch_func(const bam1_t *b, void *data);
+SEXP gap_list_fetch(SEXP pReader,SEXP pIndex,SEXP pCoords);
+SEXP gap_list_get_size(SEXP pGapList);
+SEXP get_gap_list_df(SEXP pGapList);
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 // BamRange
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 
 static void finalize_bam_range(SEXP ptr);
-static int fetch_func(const bam1_t *b, void *data);
+static int range_fetch_func(const bam1_t *b, void *data);
+static int range_fetch_complex_func(const bam1_t *b,void *data);
 SEXP bam_range_init();
-SEXP bam_range_fetch(SEXP pReader,SEXP pIndex,SEXP pCoords);
+SEXP bam_range_fetch(SEXP pReader,SEXP pIndex,SEXP pCoords,SEXP pComplex);
 SEXP bam_range_get_size(SEXP pRange);
 SEXP bam_range_get_next_align(SEXP pRange);
 SEXP bam_range_get_prev_align(SEXP pRange);
+SEXP bam_range_step_next_align(SEXP pRange);
+SEXP bam_range_step_prev_align(SEXP pRange);
 SEXP bam_range_get_align_df(SEXP pRange);
 SEXP bam_range_write(SEXP pWriter,SEXP pRange);
 SEXP bam_range_wind_back(SEXP pRange);
@@ -69,6 +95,7 @@ SEXP bam_range_pop_front(SEXP pRange);
 SEXP bam_range_write_current_align(SEXP pRange,SEXP pAlign);
 SEXP bam_range_insert_past_curr_align(SEXP pRange,SEXP pAlign);
 SEXP bam_range_insert_pre_curr_align(SEXP pRange,SEXP pAlign);
+SEXP bam_range_mv_curr_align(SEXP pSrc, SEXP pTarget);
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////
 // BamAlignment
@@ -77,13 +104,13 @@ static void finalize_bam_align(SEXP pAlign);
 SEXP bam_align_get_name(SEXP pAlign);
 SEXP bam_align_get_refid(SEXP pAlign);
 SEXP bam_align_get_position(SEXP pAlign);
-SEXP bam_align_get_cigar_size(SEXP pAlign);
+SEXP bam_align_get_nCigar(SEXP pAlign);
 SEXP bam_align_get_cigar_df(SEXP pAlign);
 SEXP bam_align_get_mate_refid(SEXP pAlign);
 SEXP bam_align_get_mate_position(SEXP pAlign);
 SEXP bam_align_get_insert_size(SEXP pAlign);
 SEXP bam_align_get_map_quality(SEXP pAlign);
-SEXP bam_align_get_read_bases(SEXP pAlign);
+SEXP bam_align_get_segment_sequence(SEXP pAlign);
 SEXP bam_align_get_qualities(SEXP pAlign);
 
 ///////////////////////////////////////////////////////////
